package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbNews;
import com.ruoyi.hezhi.domain.vo.NewsVO;

import java.util.List;

/**
 * 新闻咨询Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-14
 */
public interface TbNewsMapper
{
    /**
     * 查询新闻咨询
     *
     * @param newsId 新闻咨询主键
     * @return 新闻咨询
     */
    public TbNews selectTbNewsByNewsId(Long newsId);

    /**
     * 查询新闻咨询列表
     *
     * @param tbNews 新闻咨询
     * @return 新闻咨询集合
     */
    public List<TbNews> selectTbNewsList(TbNews tbNews);

    /**
     * 新增新闻咨询
     *
     * @param tbNews 新闻咨询
     * @return 结果
     */
    public int insertTbNews(TbNews tbNews);

    /**
     * 修改新闻咨询
     *
     * @param tbNews 新闻咨询
     * @return 结果
     */
    public int updateTbNews(TbNews tbNews);

    /**
     * 删除新闻咨询
     *
     * @param newsId 新闻咨询主键
     * @return 结果
     */
    public int deleteTbNewsByNewsId(Long newsId);

    /**
     * 批量删除新闻咨询
     *
     * @param newsIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbNewsByNewsIds(Long[] newsIds);

    /**
     * 查询新闻咨询列表
     *
     * @param tbNews 新闻咨询
     * @return 新闻咨询集合
     */
    public List<NewsVO> selectNewsList(TbNews tbNews);
}
